@@ -36,7 +36,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v10.0.8"
+		Version = "v10.0.9"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -143,7 +143,7 @@ multi-user system, this will help ensure that other local users cannot
 access the shared secret and receive the files instead of the intended
 recipient.
 
-Do you wish to continue to DISABLE the classic mode? (Y/n) `)
+Do you wish to continue to DISABLE the classic mode? (y/N) `)
 				choice := strings.ToLower(utils.GetInput(""))
 				if choice == "y" || choice == "yes" {
 					os.Remove(classicFile)
