@@ -1210,8 +1210,9 @@ func (c *Client) processMessageFileInfo(m message.Message) (done bool, err error
 			return true, fmt.Errorf("invalid path detected: '%s'", fi.FolderRemote)
 		}
 		// Issue #595 - disallow filenames with invisible characters
-		if !utils.ValidFileName(path.Join(c.FilesToTransfer[i].FolderRemote, fi.Name)) {
-			return true, fmt.Errorf("invalid filename detected: '%s'", fi.Name)
+		errFileName := utils.ValidFileName(path.Join(c.FilesToTransfer[i].FolderRemote, fi.Name))
+		if errFileName != nil {
+			return true, errFileName
 		}
 	}
 	c.TotalNumberOfContents = 0
